==> knative-model-6.4.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaNetSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KafkaNetSpecFluentImpl<A extends KafkaNetSpecFluent<A>> extends BaseFluent<A> implements KafkaNetSpecFluent<A>{
  public KafkaNetSpecFluentImpl() {
  }
  public KafkaNetSpecFluentImpl(KafkaNetSpec instance) {
    this.withSasl(instance.getSasl()); 
    this.withTls(instance.getTls()); 
  }
  private KafkaSASLSpecBuilder sasl;
  private KafkaTLSSpecBuilder tls;
  
  /**
   * This method has been deprecated, please use method buildSasl instead.
   * @return The buildable object.
   */
  @Deprecated
  public KafkaSASLSpec getSasl() {
    return this.sasl!=null ?this.sasl.build():null;
  }
  public KafkaSASLSpec buildSasl() {
    return this.sasl!=null ?this.sasl.build():null;
  }
  public A withSasl(KafkaSASLSpec sasl) {
    _visitables.get("sasl").remove(this.sasl);
    if (sasl!=null){ this.sasl= new KafkaSASLSpecBuilder(sasl); _visitables.get("sasl").add(this.sasl);} else { this.sasl = null; _visitables.get("sasl").remove(this.sasl); } return (A) this;
  }
  public Boolean hasSasl() {
    return this.sasl != null;
  }
  public KafkaNetSpecFluent.SaslNested<A> withNewSasl() {
    return new KafkaNetSpecFluentImpl.SaslNestedImpl();
  }
  public KafkaNetSpecFluent.SaslNested<A> withNewSaslLike(KafkaSASLSpec item) {
    return new KafkaNetSpecFluentImpl.SaslNestedImpl(item);
  }
  public KafkaNetSpecFluent.SaslNested<A> editSasl() {
    return withNewSaslLike(getSasl());
  }
  public KafkaNetSpecFluent.SaslNested<A> editOrNewSasl() {
    return withNewSaslLike(getSasl() != null ? getSasl(): new KafkaSASLSpecBuilder().build());
  }
  public KafkaNetSpecFluent.SaslNested<A> editOrNewSaslLike(KafkaSASLSpec item) {
    return withNewSaslLike(getSasl() != null ? getSasl(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public KafkaTLSSpec getTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public KafkaTLSSpec buildTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public A withTls(KafkaTLSSpec tls) {
    _visitables.get("tls").remove(this.tls);
    if (tls!=null){ this.tls= new KafkaTLSSpecBuilder(tls); _visitables.get("tls").add(this.tls);} else { this.tls = null; _visitables.get("tls").remove(this.tls); } return (A) this;
  }
  public Boolean hasTls() {
    return this.tls != null;
  }
  public KafkaNetSpecFluent.TlsNested<A> withNewTls() {
    return new KafkaNetSpecFluentImpl.TlsNestedImpl();
  }
  public KafkaNetSpecFluent.TlsNested<A> withNewTlsLike(KafkaTLSSpec item) {
    return new KafkaNetSpecFluentImpl.TlsNestedImpl(item);
  }
  public KafkaNetSpecFluent.TlsNested<A> editTls() {
    return withNewTlsLike(getTls());
  }
  public KafkaNetSpecFluent.TlsNested<A> editOrNewTls() {
    return withNewTlsLike(getTls() != null ? getTls(): new KafkaTLSSpecBuilder().build());
  }
  public KafkaNetSpecFluent.TlsNested<A> editOrNewTlsLike(KafkaTLSSpec item) {
    return withNewTlsLike(getTls() != null ? getTls(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    KafkaNetSpecFluentImpl that = (KafkaNetSpecFluentImpl) o;
    if (sasl != null ? !sasl.equals(that.sasl) :that.sasl != null) return false;
    if (tls != null ? !tls.equals(that.tls) :that.tls != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(sasl,  tls,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (sasl != null) { sb.append("sasl:"); sb.append(sasl + ","); }
    if (tls != null) { sb.append("tls:"); sb.append(tls); }
    sb.append("}");
    return sb.toString();
  }
  class SaslNestedImpl<N> extends KafkaSASLSpecFluentImpl<KafkaNetSpecFluent.SaslNested<N>> implements KafkaNetSpecFluent.SaslNested<N>,Nested<N>{
    SaslNestedImpl(KafkaSASLSpec item) {
      this.builder = new KafkaSASLSpecBuilder(this, item);
    }
    SaslNestedImpl() {
      this.builder = new KafkaSASLSpecBuilder(this);
    }
    KafkaSASLSpecBuilder builder;
    public N and() {
      return (N) KafkaNetSpecFluentImpl.this.withSasl(builder.build());
    }
    public N endSasl() {
      return and();
    }
    
  }
  class TlsNestedImpl<N> extends KafkaTLSSpecFluentImpl<KafkaNetSpecFluent.TlsNested<N>> implements KafkaNetSpecFluent.TlsNested<N>,Nested<N>{
    TlsNestedImpl(KafkaTLSSpec item) {
      this.builder = new KafkaTLSSpecBuilder(this, item);
    }
    TlsNestedImpl() {
      this.builder = new KafkaTLSSpecBuilder(this);
    }
    KafkaTLSSpecBuilder builder;
    public N and() {
      return (N) KafkaNetSpecFluentImpl.this.withTls(builder.build());
    }
    public N endTls() {
      return and();
    }
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/KafkaNetSpecFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class KafkaNetSpecFluentImpl<A extends KafkaNetSpecFluent<A>> extends BaseFluent<A> implements KafkaNetSpecFluent<A>{
  public KafkaNetSpecFluentImpl() {
  }
  public KafkaNetSpecFluentImpl(KafkaNetSpec instance) {
    if (instance != null) {
      this.withSasl(instance.getSasl());
      this.withTls(instance.getTls());
    }
  }
  private KafkaSASLSpecBuilder sasl;
  private KafkaTLSSpecBuilder tls;
  
  /**
   * This method has been deprecated, please use method buildSasl instead.
   * @return The buildable object.
   */
  @Deprecated
  public KafkaSASLSpec getSasl() {
    return this.sasl!=null ?this.sasl.build():null;
  }
  public KafkaSASLSpec buildSasl() {
    return this.sasl!=null ?this.sasl.build():null;
  }
  public A withSasl(KafkaSASLSpec sasl) {
    _visitables.get("sasl").remove(this.sasl);
    if (sasl!=null){ this.sasl= new KafkaSASLSpecBuilder(sasl); _visitables.get("sasl").add(this.sasl);} else { this.sasl = null; _visitables.get("sasl").remove(this.sasl); } return (A) this;
  }
  public Boolean hasSasl() {
    return this.sasl != null;
  }
  public KafkaNetSpecFluentImpl.SaslNested<A> withNewSasl() {
    return new KafkaNetSpecFluentImpl.SaslNestedImpl();
  }
  public KafkaNetSpecFluentImpl.SaslNested<A> withNewSaslLike(KafkaSASLSpec item) {
    return new KafkaNetSpecFluentImpl.SaslNestedImpl(item);
  }
  public KafkaNetSpecFluentImpl.SaslNested<A> editSasl() {
    return withNewSaslLike(getSasl());
  }
  public KafkaNetSpecFluentImpl.SaslNested<A> editOrNewSasl() {
    return withNewSaslLike(getSasl() != null ? getSasl(): new KafkaSASLSpecBuilder().build());
  }
  public KafkaNetSpecFluentImpl.SaslNested<A> editOrNewSaslLike(KafkaSASLSpec item) {
    return withNewSaslLike(getSasl() != null ? getSasl(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildTls instead.
   * @return The buildable object.
   */
  @Deprecated
  public KafkaTLSSpec getTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public KafkaTLSSpec buildTls() {
    return this.tls!=null ?this.tls.build():null;
  }
  public A withTls(KafkaTLSSpec tls) {
    _visitables.get("tls").remove(this.tls);
    if (tls!=null){ this.tls= new KafkaTLSSpecBuilder(tls); _visitables.get("tls").add(this.tls);} else { this.tls = null; _visitables.get("tls").remove(this.tls); } return (A) this;
  }
  public Boolean hasTls() {
    return this.tls != null;
  }
  public KafkaNetSpecFluentImpl.TlsNested<A> withNewTls() {
    return new KafkaNetSpecFluentImpl.TlsNestedImpl();
  }
  public KafkaNetSpecFluentImpl.TlsNested<A> withNewTlsLike(KafkaTLSSpec item) {
    return new KafkaNetSpecFluentImpl.TlsNestedImpl(item);
  }
  public KafkaNetSpecFluentImpl.TlsNested<A> editTls() {
    return withNewTlsLike(getTls());
  }
  public KafkaNetSpecFluentImpl.TlsNested<A> editOrNewTls() {
    return withNewTlsLike(getTls() != null ? getTls(): new KafkaTLSSpecBuilder().build());
  }
  public KafkaNetSpecFluentImpl.TlsNested<A> editOrNewTlsLike(KafkaTLSSpec item) {
    return withNewTlsLike(getTls() != null ? getTls(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    KafkaNetSpecFluentImpl that = (KafkaNetSpecFluentImpl) o;
    if (!java.util.Objects.equals(sasl, that.sasl)) return false;

    if (!java.util.Objects.equals(tls, that.tls)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(sasl,  tls,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (sasl != null) { sb.append("sasl:"); sb.append(sasl + ","); }
    if (tls != null) { sb.append("tls:"); sb.append(tls); }
    sb.append("}");
    return sb.toString();
  }
  class SaslNestedImpl<N> extends KafkaSASLSpecFluentImpl<KafkaNetSpecFluentImpl.SaslNested<N>> implements KafkaNetSpecFluentImpl.SaslNested<N>,Nested<N>{
    SaslNestedImpl(KafkaSASLSpec item) {
      this.builder = new KafkaSASLSpecBuilder(this, item);
    }
    SaslNestedImpl() {
      this.builder = new KafkaSASLSpecBuilder(this);
    }
    KafkaSASLSpecBuilder builder;
    public N and() {
      return (N) KafkaNetSpecFluentImpl.this.withSasl(builder.build());
    }
    public N endSasl() {
      return and();
    }
    
  }
  class TlsNestedImpl<N> extends KafkaTLSSpecFluentImpl<KafkaNetSpecFluentImpl.TlsNested<N>> implements KafkaNetSpecFluentImpl.TlsNested<N>,Nested<N>{
    TlsNestedImpl(KafkaTLSSpec item) {
      this.builder = new KafkaTLSSpecBuilder(this, item);
    }
    TlsNestedImpl() {
      this.builder = new KafkaTLSSpecBuilder(this);
    }
    KafkaTLSSpecBuilder builder;
    public N and() {
      return (N) KafkaNetSpecFluentImpl.this.withTls(builder.build());
    }
    public N endTls() {
      return and();
    }
    
  }
  
}
